==> jc-1.4.0.tar.gz: gnu/xml/xpath/DocumentOrderComparator.c <==
// public class gnu.xml.xpath.DocumentOrderComparator

// class file dependencies
// @dep_class 5a73d1e4b532a2a5 gnu_xml_xpath_DocumentOrderComparator
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 1ad5438e0f3ab7fd java_util_Comparator
// @dep_class 2f4d9ed11c447a44 org_w3c_dom_Node

// header file dependencies
// @dep_header gnu_xml_xpath_DocumentOrderComparator
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_util_Comparator
// @dep_header org_w3c_dom_Node

#include "jc_defs.h"

#include "gnu/xml/xpath/DocumentOrderComparator.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/util/Comparator.h"
#include "org/w3c/dom/Node.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_gnu_xml_xpath_DocumentOrderComparator$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_gnu_xml_xpath_DocumentOrderComparator$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_gnu_xml_xpath_DocumentOrderComparator$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_gnu_xml_xpath_DocumentOrderComparator$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_gnu_xml_xpath_DocumentOrderComparator$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_gnu_xml_xpath_DocumentOrderComparator$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_gnu_xml_xpath_DocumentOrderComparator$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_xml_xpath_DocumentOrderComparator, _init$52f4ad9f2989aeee);

void
_jc_gnu_xml_xpath_DocumentOrderComparator$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_gnu_xml_xpath_DocumentOrderComparator$object *this)
{
	struct _jc_gnu_xml_xpath_DocumentOrderComparator$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(48);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public int compare(java.lang.Object, java.lang.Object)
//

static _jc_linenum _jc_gnu_xml_xpath_DocumentOrderComparator$linenum_table$compare$ef65339aa5f9531b[];

static const unsigned char _jc_gnu_xml_xpath_DocumentOrderComparator$param_ptypes$compare$ef65339aa5f9531b[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_INT };

static _jc_type *const _jc_gnu_xml_xpath_DocumentOrderComparator$param_types$compare$ef65339aa5f9531b[] = {
	&_jc_java_lang_Object$type,
	&_jc_java_lang_Object$type
};

_jc_method _jc_gnu_xml_xpath_DocumentOrderComparator$method_info$compare$ef65339aa5f9531b = {
	.name=			"compare",
	.signature=		"(Ljava/lang/Object;Ljava/lang/Object;)I",
	.class=			&_jc_gnu_xml_xpath_DocumentOrderComparator$type,
	.param_types=		&_jc_gnu_xml_xpath_DocumentOrderComparator$param_types$compare$ef65339aa5f9531b,
	.return_type=		&_jc_int$prim$type,
	.param_ptypes=		&_jc_gnu_xml_xpath_DocumentOrderComparator$param_ptypes$compare$ef65339aa5f9531b,
	.signature_hash=	_JC_JLONG(0xef65339aa5f9531b),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_gnu_xml_xpath_DocumentOrderComparator$method$compare$ef65339aa5f9531b,
	.vtable_index=		_JC_OFFSETOF(struct _jc_gnu_xml_xpath_DocumentOrderComparator$vtable, gnu_xml_xpath_DocumentOrderComparator.compare$ef65339aa5f9531b) / sizeof(void *),
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	5,
	      .table=	_jc_gnu_xml_xpath_DocumentOrderComparator$linenum_table$compare$ef65339aa5f9531b
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_xml_xpath_DocumentOrderComparator, compare$ef65339aa5f9531b);

jint
_jc_gnu_xml_xpath_DocumentOrderComparator$method$compare$ef65339aa5f9531b(_jc_env *const env, _jc_gnu_xml_xpath_DocumentOrderComparator$object *this, _jc_java_lang_Object$object *param0, _jc_java_lang_Object$object *param1)
{
	struct _jc_gnu_xml_xpath_DocumentOrderComparator$object *r0;
	struct _jc_java_lang_Object$object *r1;
	struct _jc_java_lang_Object$object *r2;
	struct _jc_object *r3;
	struct _jc_object *r4;
	jshort s0;
	jboolean z0;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(54);				// 0
	z0 = _JC_INSTANCEOF(env, r1, &_jc_org_w3c_dom_Node$type);
	if (z0 == 0)
		goto label0;
	z0 = _JC_INSTANCEOF(env, r2, &_jc_org_w3c_dom_Node$type);
	if (z0 == 0)
		goto label0;
	_JC_LINE_NUMBER(56);				// 1
	r3 = r1;
	_JC_LINE_NUMBER(57);				// 2
	r4 = r2;
	_JC_LINE_NUMBER(58);				// 3
	s0 = _JC_INVOKE_INTERFACE(env, r3, _JC_JLONG(0xf9e9cd7ce70bf56b), jshort, r4);
	return s0;

label0:
	_JC_LINE_NUMBER(60);				// 4
	return 0;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_gnu_xml_xpath_DocumentOrderComparator$methods[] = {
	&_jc_gnu_xml_xpath_DocumentOrderComparator$method_info$_init$52f4ad9f2989aeee,
	&_jc_gnu_xml_xpath_DocumentOrderComparator$method_info$compare$ef65339aa5f9531b
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_gnu_xml_xpath_DocumentOrderComparator$interfaces[] = {
	&_jc_java_util_Comparator$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_gnu_xml_xpath_DocumentOrderComparator$imethod_hash_bucket_1[] = {
	&_jc_java_lang_Object$method_info$equals$8a15e0625571c581,
	_JC_NULL
};
static _jc_method *_jc_gnu_xml_xpath_DocumentOrderComparator$imethod_hash_bucket_27[] = {
	&_jc_gnu_xml_xpath_DocumentOrderComparator$method_info$compare$ef65339aa5f9531b,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_gnu_xml_xpath_DocumentOrderComparator$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[1]=	_jc_gnu_xml_xpath_DocumentOrderComparator$imethod_hash_bucket_1,
	[27]=	_jc_gnu_xml_xpath_DocumentOrderComparator$imethod_hash_bucket_27
};

// Interface "quick" lookup hash table
static const void *_jc_gnu_xml_xpath_DocumentOrderComparator$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[1]=	&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	[27]=	&_jc_gnu_xml_xpath_DocumentOrderComparator$method$compare$ef65339aa5f9531b
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_gnu_xml_xpath_DocumentOrderComparator$instanceof_hash_bucket_37[] = {
	&_jc_gnu_xml_xpath_DocumentOrderComparator$type,
	_JC_NULL
};
static _jc_type *const _jc_gnu_xml_xpath_DocumentOrderComparator$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_gnu_xml_xpath_DocumentOrderComparator$instanceof_hash_bucket_125[] = {
	&_jc_java_util_Comparator$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_gnu_xml_xpath_DocumentOrderComparator$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[37]=	_jc_gnu_xml_xpath_DocumentOrderComparator$instanceof_hash_bucket_37,
	[113]=	_jc_gnu_xml_xpath_DocumentOrderComparator$instanceof_hash_bucket_113,
	[125]=	_jc_gnu_xml_xpath_DocumentOrderComparator$instanceof_hash_bucket_125
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_gnu_xml_xpath_DocumentOrderComparator$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/util/Comparator",	_JC_JLONG(0x1ad5438e0f3ab7fd) },
	{ "org/w3c/dom/Node",	_JC_JLONG(0x2f4d9ed11c447a44) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_gnu_xml_xpath_DocumentOrderComparator$vtype _jc_gnu_xml_xpath_DocumentOrderComparator$type = {
    .type= {
	.name=			"gnu/xml/xpath/DocumentOrderComparator",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_gnu_xml_xpath_DocumentOrderComparator$interfaces) / sizeof(*_jc_gnu_xml_xpath_DocumentOrderComparator$interfaces),
	.interfaces=		_jc_gnu_xml_xpath_DocumentOrderComparator$interfaces,
	.imethod_hash_table=	_jc_gnu_xml_xpath_DocumentOrderComparator$imethod_hash_table,
	.imethod_quick_table=	_jc_gnu_xml_xpath_DocumentOrderComparator$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x5a73d1e4b532a2a5),
		.source_file=		"DocumentOrderComparator.java",
		.instance_size=		sizeof(_jc_gnu_xml_xpath_DocumentOrderComparator$refs) + sizeof(_jc_gnu_xml_xpath_DocumentOrderComparator$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_gnu_xml_xpath_DocumentOrderComparator$methods) / sizeof(*_jc_gnu_xml_xpath_DocumentOrderComparator$methods),
		.methods=		_jc_gnu_xml_xpath_DocumentOrderComparator$methods,
		.instanceof_hash_table=	_jc_gnu_xml_xpath_DocumentOrderComparator$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_gnu_xml_xpath_DocumentOrderComparator$class_depends) / sizeof(*_jc_gnu_xml_xpath_DocumentOrderComparator$class_depends),
		.class_depends=		_jc_gnu_xml_xpath_DocumentOrderComparator$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.gnu_xml_xpath_DocumentOrderComparator= {
	    .compare$ef65339aa5f9531b=
		&_jc_gnu_xml_xpath_DocumentOrderComparator$method$compare$ef65339aa5f9531b,
	},
    }
};

==> jc-1.4.5.tar.gz: gnu/xml/xpath/DocumentOrderComparator.c <==
// public class gnu.xml.xpath.DocumentOrderComparator

// class file dependencies
// @dep_class 5a73d1e4b532a2a5 gnu_xml_xpath_DocumentOrderComparator
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 1ad5438e0f3ab7fd java_util_Comparator
// @dep_class 2f4d9ed11c447a44 org_w3c_dom_Node

// header file dependencies
// @dep_header gnu_xml_xpath_DocumentOrderComparator
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_util_Comparator
// @dep_header org_w3c_dom_Node

#include "jc_defs.h"

#include "gnu/xml/xpath/DocumentOrderComparator.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/util/Comparator.h"
#include "org/w3c/dom/Node.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_gnu_xml_xpath_DocumentOrderComparator$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_gnu_xml_xpath_DocumentOrderComparator$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_gnu_xml_xpath_DocumentOrderComparator$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_gnu_xml_xpath_DocumentOrderComparator$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_gnu_xml_xpath_DocumentOrderComparator$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_gnu_xml_xpath_DocumentOrderComparator$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_gnu_xml_xpath_DocumentOrderComparator$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_xml_xpath_DocumentOrderComparator, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_gnu_xml_xpath_DocumentOrderComparator$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_gnu_xml_xpath_DocumentOrderComparator$object *this)
{
	struct _jc_gnu_xml_xpath_DocumentOrderComparator$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(48);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public int compare(java.lang.Object, java.lang.Object)
//

static _jc_linenum _jc_gnu_xml_xpath_DocumentOrderComparator$linenum_table$compare$ef65339aa5f9531b[];

static const unsigned char _jc_gnu_xml_xpath_DocumentOrderComparator$param_ptypes$compare$ef65339aa5f9531b[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_INT };

static _jc_type *const _jc_gnu_xml_xpath_DocumentOrderComparator$param_types$compare$ef65339aa5f9531b[] = {
	&_jc_java_lang_Object$type,
	&_jc_java_lang_Object$type
};

_jc_method _jc_gnu_xml_xpath_DocumentOrderComparator$method_info$compare$ef65339aa5f9531b = {
	.name=			"compare",
	.signature=		"(Ljava/lang/Object;Ljava/lang/Object;)I",
	.class=			&_jc_gnu_xml_xpath_DocumentOrderComparator$type,
	.param_types=		&_jc_gnu_xml_xpath_DocumentOrderComparator$param_types$compare$ef65339aa5f9531b,
	.return_type=		&_jc_int$prim$type,
	.param_ptypes=		&_jc_gnu_xml_xpath_DocumentOrderComparator$param_ptypes$compare$ef65339aa5f9531b,
	.signature_hash=	_JC_JLONG(0xef65339aa5f9531b),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_gnu_xml_xpath_DocumentOrderComparator$method$compare$ef65339aa5f9531b,
	.vtable_index=		_JC_OFFSETOF(struct _jc_gnu_xml_xpath_DocumentOrderComparator$vtable, gnu_xml_xpath_DocumentOrderComparator.compare$ef65339aa5f9531b) / sizeof(void *),
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	5,
	      .table=	_jc_gnu_xml_xpath_DocumentOrderComparator$linenum_table$compare$ef65339aa5f9531b
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_xml_xpath_DocumentOrderComparator, compare$ef65339aa5f9531b);

jint _JC_JCNI_ATTR
_jc_gnu_xml_xpath_DocumentOrderComparator$method$compare$ef65339aa5f9531b(_jc_env *const env, _jc_gnu_xml_xpath_DocumentOrderComparator$object *this, _jc_java_lang_Object$object *param0, _jc_java_lang_Object$object *param1)
{
	struct _jc_gnu_xml_xpath_DocumentOrderComparator$object *r0;
	struct _jc_java_lang_Object$object *r1;
	struct _jc_java_lang_Object$object *r2;
	struct _jc_object *r3;
	struct _jc_object *r4;
	jshort s0;
	jboolean z0;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(54);				// 0
	z0 = _JC_INSTANCEOF(env, r1, &_jc_org_w3c_dom_Node$type);
	if (z0 == 0)
		goto label0;
	z0 = _JC_INSTANCEOF(env, r2, &_jc_org_w3c_dom_Node$type);
	if (z0 == 0)
		goto label0;
	_JC_LINE_NUMBER(56);				// 1
	r3 = r1;
	_JC_LINE_NUMBER(57);				// 2
	r4 = r2;
	_JC_LINE_NUMBER(58);				// 3
	s0 = _JC_INVOKE_INTERFACE(env, r3, _JC_JLONG(0xf9e9cd7ce70bf56b), jshort, (_jc_env *, struct _jc_object *, struct _jc_object *), r4);
	return s0;

label0:
	_JC_LINE_NUMBER(60);				// 4
	return 0;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_gnu_xml_xpath_DocumentOrderComparator$methods[] = {
	&_jc_gnu_xml_xpath_DocumentOrderComparator$method_info$_init$52f4ad9f2989aeee,
	&_jc_gnu_xml_xpath_DocumentOrderComparator$method_info$compare$ef65339aa5f9531b
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_gnu_xml_xpath_DocumentOrderComparator$interfaces[] = {
	&_jc_java_util_Comparator$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_gnu_xml_xpath_DocumentOrderComparator$imethod_hash_bucket_1[] = {
	&_jc_java_lang_Object$method_info$equals$8a15e0625571c581,
	_JC_NULL
};
static _jc_method *_jc_gnu_xml_xpath_DocumentOrderComparator$imethod_hash_bucket_27[] = {
	&_jc_gnu_xml_xpath_DocumentOrderComparator$method_info$compare$ef65339aa5f9531b,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_gnu_xml_xpath_DocumentOrderComparator$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[1]=	_jc_gnu_xml_xpath_DocumentOrderComparator$imethod_hash_bucket_1,
	[27]=	_jc_gnu_xml_xpath_DocumentOrderComparator$imethod_hash_bucket_27
};

// Interface "quick" lookup hash table
static const void *_jc_gnu_xml_xpath_DocumentOrderComparator$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[1]=	&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	[27]=	&_jc_gnu_xml_xpath_DocumentOrderComparator$method$compare$ef65339aa5f9531b
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_gnu_xml_xpath_DocumentOrderComparator$instanceof_hash_bucket_37[] = {
	&_jc_gnu_xml_xpath_DocumentOrderComparator$type,
	_JC_NULL
};
static _jc_type *const _jc_gnu_xml_xpath_DocumentOrderComparator$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_gnu_xml_xpath_DocumentOrderComparator$instanceof_hash_bucket_125[] = {
	&_jc_java_util_Comparator$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_gnu_xml_xpath_DocumentOrderComparator$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[37]=	_jc_gnu_xml_xpath_DocumentOrderComparator$instanceof_hash_bucket_37,
	[101]=	_jc_gnu_xml_xpath_DocumentOrderComparator$instanceof_hash_bucket_101,
	[125]=	_jc_gnu_xml_xpath_DocumentOrderComparator$instanceof_hash_bucket_125
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_gnu_xml_xpath_DocumentOrderComparator$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/util/Comparator",	_JC_JLONG(0x1ad5438e0f3ab7fd) },
	{ "org/w3c/dom/Node",	_JC_JLONG(0x2f4d9ed11c447a44) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_gnu_xml_xpath_DocumentOrderComparator$vtype _jc_gnu_xml_xpath_DocumentOrderComparator$type = {
    .type= {
	.name=			"gnu/xml/xpath/DocumentOrderComparator",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_gnu_xml_xpath_DocumentOrderComparator$interfaces) / sizeof(*_jc_gnu_xml_xpath_DocumentOrderComparator$interfaces),
	.interfaces=		_jc_gnu_xml_xpath_DocumentOrderComparator$interfaces,
	.imethod_hash_table=	_jc_gnu_xml_xpath_DocumentOrderComparator$imethod_hash_table,
	.imethod_quick_table=	_jc_gnu_xml_xpath_DocumentOrderComparator$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x5a73d1e4b532a2a5),
		.source_file=		"DocumentOrderComparator.java",
		.instance_size=		sizeof(_jc_gnu_xml_xpath_DocumentOrderComparator$refs) + sizeof(_jc_gnu_xml_xpath_DocumentOrderComparator$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_gnu_xml_xpath_DocumentOrderComparator$methods) / sizeof(*_jc_gnu_xml_xpath_DocumentOrderComparator$methods),
		.methods=		_jc_gnu_xml_xpath_DocumentOrderComparator$methods,
		.instanceof_hash_table=	_jc_gnu_xml_xpath_DocumentOrderComparator$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_gnu_xml_xpath_DocumentOrderComparator$class_depends) / sizeof(*_jc_gnu_xml_xpath_DocumentOrderComparator$class_depends),
		.class_depends=		_jc_gnu_xml_xpath_DocumentOrderComparator$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.gnu_xml_xpath_DocumentOrderComparator= {
	    .compare$ef65339aa5f9531b=
		&_jc_gnu_xml_xpath_DocumentOrderComparator$method$compare$ef65339aa5f9531b,
	},
    }
};
